@@ -7,17 +7,6 @@ log = logging.getLogger(__name__)
 
 
 class Jira(AtlassianRestAPI):
-    def server_info(self, do_health_check=False):
-        """
-        Returns general information about the current JIRA server.
-        :param do_health_check:
-        :return:
-        """
-        params = {'doHealthCheck': False}
-        if do_health_check:
-            params['doHealthCheck'] = do_health_check
-        return self.get('rest/api/2/serverInfo', params=params)
-
     def reindex_status(self):
         return self.get('rest/api/2/reindex')
 
@@ -126,6 +115,57 @@ class Jira(AtlassianRestAPI):
         url = 'rest/api/2/user?username={0}'.format(username)
         return self.put(url, data=data)
 
+    def user_create(self, username, email, password, display_name):
+        """
+        Create a user in Jira
+        :param username:
+        :param email:
+        :param password:
+        :param display_name:
+        :return:
+        """
+        log.warning('Creating user {}'.format(display_name))
+        data = {'password': password,
+                'emailAddress': email,
+                'displayName': display_name,
+                'name': username}
+        return self.post('rest/api/2/user', data=data)
+
+    def user_properties(self, username):
+        """
+        Get user property
+        :param username:
+        :return:
+        """
+        return self.get('rest/api/2/user/properties?username={}'.format(username))
+
+    def user_property(self, username, key_property):
+        """
+        Get user property
+        :param username:
+        :return:
+        """
+        params = {'username': username}
+        return self.get('rest/api/2/user/properties/{}'.format(key_property), params=params)
+
+    def user_set_property(self, username, key_property, value_property):
+        """
+        Set property for user
+        :param username:
+        :param key_property:
+        :param value_property:
+        :return:
+        """
+        url = 'rest/api/2/user/properties/{key_property}?username={user_name}'.format(key_property=key_property,
+                                                                                      user_name=username)
+        data = {'value': value_property}
+        return self.put(url, data=data)
+
+    def user_delete_property(self, username, key_property):
+        url = 'rest/api/2/user/properties/{}'.format(key_property)
+        params = {'username': username}
+        return self.delete(url, params=params)
+
     def user_update_email(self, username, email):
         """
         Update user email for new domain changes
